@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.008001;
 
-our $VERSION = '0.002000';
+our $VERSION = '0.002001';
 
 use constant DECLARE_NAME => 1;
 use constant DECLARE_PROTO => 2;
@@ -485,13 +485,15 @@ Devel::Declare -
 
 Currently valid op types: 'check', 'rv2cv'
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Matt S Trout - <mst@shadowcat.co.uk>
 
 Company: http://www.shadowcat.co.uk/
 Blog: http://chainsawblues.vox.com/
 
+Florian Ragwitz E<lt>rafl@debian.orgE<gt>
+
 =head1 LICENSE
 
 This library is free software under the same terms as perl itself
